#
# spec file for package python-pybtex
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define oname   pybtex

Name:           python-pybtex
Version:        0.18
Release:        9.7
Summary:        BibTeX-compatible Bibliography Processor in Python
License:        MIT
Group:          Productivity/Publishing/TeX/Utilities
Url:            http://pybtex.org/
Source0:        http://pypi.python.org/packages/source/p/%{oname}/%{oname}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-pyparsing
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Pybtex is a BibTeX-compatible bibliography processor written in Python which
can produce formatted bibliographies in different, customizable formats. It
supports both native BibTeX style files and styles written in Python and
accepts BibTeX, BibTeXML, and a custom YAML-based bibligraphy input format and
can output LaTeX, HTML, and plain text.

Furthermore, Pybtex provides an interface for Python applications which need to
process the above formats.

%package -n %{name}-doc
Summary:        Documentation for the python-pybtex
Group:          Documentation
BuildArch:      noarch

%description -n %{name}-doc
Pybtex is a BibTeX-compatible bibliography processor written in Python which
can produce formatted bibliographies in different, customizable formats. It
supports both native BibTeX style files and styles written in Python and
accepts BibTeX, BibTeXML, and a custom YAML-based bibligraphy input format and
can output LaTeX, HTML, and plain text.

Furthermore, Pybtex provides an interface for Python applications which need to
process the above formats.


Documentation for the package python-pybtex.

%prep
%setup -q -n %{oname}-%{version}

# Fix URL
sed -i 's|http://pybtex.sourceforge.net/|%{url}|' setup.py

# prevent tests from being installed
rm -rf %{oname}/tests

# Remove Shebang
find %{oname}/ -name '*.py' -print0 | xargs -0 sed -i 's|/usr/bin/env||'

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# install man
for man in %{oname} %{oname}-convert %{oname}-format ; do
install -Dm 0644 docs/man1/${man}.1 %{buildroot}%{_mandir}/man1/${man}.1
done

%if 0%{?suse_version}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root,-)
%{_bindir}/%{oname}*
%{_mandir}/man1/%{oname}.1%{ext_man}
%{_mandir}/man1/%{oname}-convert.1%{ext_man}
%{_mandir}/man1/%{oname}-format.1%{ext_man}
%{python_sitelib}/%{oname}
%{python_sitelib}/custom_fixers
%{python_sitelib}/%{oname}-%{version}-py%{py_ver}.egg-info

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc docs/html examples COPYING CHANGES README

%changelog
* Sun Jul 12 2015 nemysis@gmx.ch
- Use %%{oname} instead of pybtex
- Change Url from SourceForge to http://pybtex.org
- Add python-pybtex-rpmlintrc, executable script in documentation
- Use check for openSUSE %%if 0%%{?suse_version}
- Remove Recommends for non existent python-yaml
- Split out doc and add doc into subpackages
- Remove BuildRequires for ed, use sed instead
- Add sed, Fix URL
- Change Man Pages, add pybtex-format
- Add examples to Documentation
* Tue Aug 26 2014 gber@opensuse.org
- update to version 0.18
  - Pybtex is now fully case-insensitive (like BibTeX). As a
    consequence, IEEEtran styles now work corretly.
  - Added ``--preserve-case`` optoin to ``pybtex-convert`` (by
    default all identifiers are converted to lower case).
  - An erorr is reported if two citations have the same key but
    different case, like in BibTeX. (Example: ddt1999 and DDT1999).
  - Fixed parsing unused bibliography entries with strings
    containing @ characters.
  - ``entry.max$`` constant is now set to 250, ``global.max$`` is
    set to 20000, like in BibTeX.
  - Added ``--strict`` option to ``pybtex-convert`` and
    ``pybtex-format`` (turns warning to errors).
  - Strict mode is now enabled by default when using pybtex as a
    library (exceptions are raised on all errors instead of just
    printing warnings to stderr).
    Non-strict error handling is still enabled when using pybtex
    from the command line, for compatibility with BibTeX. Use
    ``--strict`` option if you don't like this.
  - Added missing pybtex-format manpage.
* Mon May 26 2014 gber@opensuse.org
- update to version 0.17
  - Added pybtex-format utility for formatting bibliography files
    as HTML, LaTeX, and other supported human-readable formats.
  - Added --strict command line option (all warnings become
    errors).
  - Added alpha label style, and alpha and unsrtalpha formatting
    styles.
  - Added support for url, eprint, doi, and pubmed fields in unsrt
    style.
  - Names with hyphens are now abbreviated correctly
    ("Jean-Baptiste" becomes "J.-B.").
  - width$ now uses cmr10 font metrics, like in BibTeX. Non-latin
    characters are also supported.
  - Pythonic style engine now supports @preamble commands.
  - Warning on missing fields are now more human-readable.
  - When writing BibTeX files, put entry key on the same line with
    entry type. Fixes warnings in Jabref.
  - When using multiple .bib files, macros defined in earlier files
    are available in subsequent ones (like in BibTeX).
  - Fixed parsing .bst files with lines consisting of a single %%
    character.
  - Fixed sorting entries without author in author_year_title
    sorting style.
  - Fixed broken CaseInsensitiveDict.get().
  - CaseInsensitiveDict is now pickleable.
  - Added support for registering plugins at runtime with
    pybtex.plugin.register_plugin() - useful for using pybtex as a
    library.
* Wed May 16 2012 gber@opensuse.org
- update to version 0.16
  - BibTeX .bib and .bst parsers were completely rewritten; they
    are now much faster and more BibTeX-compatible
  - syntax errors and undefined strings in .bib files now result in
    warnings instead of errors, like in BibTeX
  - unused entries in .bib files are now skipped, like in BibTeX
  - the case of entry keys is now preserved (in previous versions
    they were converted to lowercase)
  - pythonic style engine now supports sorting
  - pythonic style engine: fixed nested optional() blocks
  - fixed parsing of some names with a Last part but no von part
  - fixed processing of brace-level-one "special characters" in
    purify$ BibTeX built-in function
  - added proper error messages on encoding errors in .bib files
  - the default encoding is now UTF-8 on all platforms
  - pybtex-convert now preserves the order of entries in BibTeX and
    BibTeXML files
  - fixed first_of behavior when non-empty child is followed by a
    child that has a missing field
  - fixed crossref lookups when key is not lower case
  - completed unsrt and plain python styles: they now contain all
    entry types
  - added doctree backend for rendering into a tree of docutils
    nodes
  - added support for non-string backends
* Mon Jun 13 2011 gber@opensuse.org
- update to version 0.15
  - changed license from GPL-3 to MIT
  - when parsing multiple BibTeX files, macros defined in earlier
    files are now available to all subsequent files, like in BibTeX
  - BibTeX .bst interpreter now prints warnings on missing entries,
    like BibTeX, instead of raising a KeyError
  - call.type$ BibTeX built-in function now uses default.entry for
    unknown entry types, like in BibTeX
  - substring$ now accepts start=0 and returns an empty string.
  - added more detailed error messages for already defined
    variables in .bst files
  - bugfixes
* Sun Jan  9 2011 gber@opensuse.org
- add documentation
* Sun Jan  9 2011 gber@opensuse.org
- initial packaging
